summaryrefslogtreecommitdiffstats
path: root/src/mesa/swrast/s_span.c
diff options
context:
space:
mode:
authorBrian Paul <[email protected]>2012-01-16 10:54:13 -0700
committerBrian Paul <[email protected]>2012-01-24 14:12:06 -0700
commit267fb178844d3f17503dd0f921791f3ab059c4e7 (patch)
tree99ce8888e59c0bebb25fd2efdf079d2da4d38ea8 /src/mesa/swrast/s_span.c
parent64be85540f30e904784c6a72f2ba2784d5ccb36d (diff)
swrast: remove dstType param from _swrast_read_rgba_span()
It was always GL_FLOAT.
Diffstat (limited to 'src/mesa/swrast/s_span.c')
-rw-r--r--src/mesa/swrast/s_span.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/mesa/swrast/s_span.c b/src/mesa/swrast/s_span.c
index f91b6c25e53..3d3ec57d397 100644
--- a/src/mesa/swrast/s_span.c
+++ b/src/mesa/swrast/s_span.c
@@ -1324,16 +1324,16 @@ end:
/**
* Read RGBA pixels from a renderbuffer. Clipping will be done to prevent
* reading ouside the buffer's boundaries.
* \param dstType datatype for returned colors
* \param rgba the returned colors
*/
void
_swrast_read_rgba_span( struct gl_context *ctx, struct gl_renderbuffer *rb,
- GLuint n, GLint x, GLint y, GLenum dstType,
+ GLuint n, GLint x, GLint y,
GLvoid *rgba)
{
+ GLenum dstType = GL_FLOAT;
const GLint bufWidth = (GLint) rb->Width;
const GLint bufHeight = (GLint) rb->Height;
@@ -1324,16 +1324,16 @@ end:
/**
- * Read RGBA pixels from a renderbuffer. Clipping will be done to prevent
- * reading ouside the buffer's boundaries.
- * \param dstType datatype for returned colors
+ * Read float RGBA pixels from a renderbuffer. Clipping will be done to
+ * prevent reading ouside the buffer's boundaries.
* \param rgba the returned colors
*/